@@ -92,7 +92,7 @@ describe 'neutron' do
     it_configures 'with transport_url defined'
     it_configures 'with rootwrap daemon'
 
-    context 'with amqp rpc_backend value' do
+    context 'with amqp messaging' do
       it_configures 'amqp support'
     end
   end
@@ -472,9 +472,7 @@ describe 'neutron' do
   end
 
   shared_examples_for 'amqp support' do
-    context 'with default parameters' do
-      before { params.merge!( :rpc_backend => 'amqp' ) }
-
+    context 'with default amqp parameters' do
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
@@ -495,7 +493,6 @@ describe 'neutron' do
 
     context 'with overriden amqp parameters' do
       before { params.merge!(
-        :rpc_backend        => 'amqp',
         :amqp_idle_timeout  => '60',
         :amqp_trace         => true,
         :amqp_ssl_ca_file   => '/path/to/ca.cert',
