@@ -66,7 +66,7 @@ describe 'neutron::server' do
         :name    => platform_params[:server_service],
         :enable  => true,
         :ensure  => 'running',
-        :tag     => ['neutron-service', 'neutron-db-sync-service'],
+        :tag     => ['neutron-service', 'neutron-db-sync-service', 'neutron-server-eventlet'],
       )
       is_expected.to contain_service('neutron-server').that_subscribes_to('Anchor[neutron::service::begin]')
       is_expected.to contain_service('neutron-server').that_notifies('Anchor[neutron::service::end]')
@@ -90,15 +90,24 @@ describe 'neutron::server' do
       end
     end
 
-    context 'with DVR enabled' do
+    context 'with DVR enabled for new routers' do
       before :each do
         params.merge!(:router_distributed => true)
       end
-      it 'should enable DVR' do
+      it 'should enable DVR for new routers' do
         is_expected.to contain_neutron_config('DEFAULT/router_distributed').with_value(true)
       end
     end
 
+    context 'with DVR disabled' do
+      before :each do
+        params.merge!(:enable_dvr => false)
+      end
+      it 'should disable DVR' do
+        is_expected.to contain_neutron_config('DEFAULT/enable_dvr').with_value(false)
+      end
+    end
+
     context 'with HA routers enabled' do
       before :each do
         params.merge!(:l3_ha => true)
@@ -131,15 +140,6 @@ describe 'neutron::server' do
       end
     end
 
-    context 'with custom service name' do
-      before :each do
-        params.merge!(:service_name => 'custom-service-name')
-      end
-      it 'should configure proper service name' do
-        is_expected.to contain_service('neutron-server').with_name('custom-service-name')
-      end
-    end
-
     context 'with state_path and lock_path parameters' do
       before :each do
         params.merge!(:state_path => 'state_path',
@@ -225,6 +225,44 @@ describe 'neutron::server' do
 
       it { is_expected.to contain_neutron_config('oslo_middleware/enable_proxy_headers_parsing').with_value(true) }
     end
+
+    context 'when running neutron-api in wsgi' do
+      before :each do
+        params.merge!({ :service_name => 'httpd' })
+      end
+
+      let :pre_condition do
+        "class { 'neutron': rabbit_password => 'passw0rd' }
+         include ::apache
+         class { '::neutron::keystone::authtoken':
+           password => 'passw0rd',
+         }"
+      end
+
+      it 'configures neutron-api service with Apache' do
+        is_expected.to contain_service('neutron-server').with(
+          :ensure     => 'stopped',
+          :name       => platform_params[:server_service],
+          :enable     => false,
+          :tag        => ['neutron-service', 'neutron-db-sync-service'],
+        )
+      end
+    end
+
+    context 'when service_name is customized' do
+      before :each do
+        params.merge!({ :service_name => 'foobar' })
+      end
+
+      it 'configures neutron-api service with custom name' do
+        is_expected.to contain_service('neutron-server').with(
+          :name    => 'foobar',
+          :enable  => true,
+          :ensure  => 'running',
+          :tag     => ['neutron-service', 'neutron-db-sync-service'],
+        )
+      end
+    end
   end
 
   shared_examples_for 'VPNaaS, FWaaS and LBaaS package installation' do
